pub fn local_ray_intersection_with_triangle(
a: Vector,
b: Vector,
c: Vector,
ray: &Ray,
) -> Option<(RayIntersection, Vector)>Expand description
Computes the intersection between a triangle and a ray.
If an intersection is found, the time of impact, the normal and the barycentric coordinates of the intersection point are returned.